@@ -56,7 +56,7 @@ class ManageShare(forms.SelfHandlingForm):
     protocol = forms.ChoiceField(
         label=_("Share Protocol"), required=True,
         choices=(('NFS', 'NFS'), ('CIFS', 'CIFS'), ('GlusterFS', 'GlusterFS'),
-                 ('HDFS', 'HDFS')))
+                 ('HDFS', 'HDFS'), ('CephFS', 'CephFS')))
     share_type = forms.ChoiceField(label=_("Share Type"), required=True)
 
     driver_options = forms.CharField(
@@ -65,6 +65,9 @@ class ManageShare(forms.SelfHandlingForm):
         help_text=_("key=value pairs per line can be set"),
         widget=forms.Textarea(
             attrs={'class': 'modal-body-fixed-width', 'rows': 2}))
+    is_public = forms.BooleanField(
+        label=_("Public"), required=False, initial=False,
+        help_text=("Defines whether this share is available for all or not."))
 
     def __init__(self, request, *args, **kwargs):
         super(ManageShare, self).__init__(request, *args, **kwargs)
@@ -106,7 +109,8 @@ class ManageShare(forms.SelfHandlingForm):
                 driver_options=driver_options,
                 share_type=data['share_type'],
                 name=data['name'],
-                description=data['description'])
+                description=data['description'],
+                is_public=data['is_public'])
 
             share_name = data.get('name', data.get('id'))
             messages.success(
@@ -174,13 +178,8 @@ class CreateShareType(forms.SelfHandlingForm):
                 raise ValidationError(message=msg)
 
             share_type = manila.share_type_create(
-                request, data["name"], spec_dhss, data["is_public"])
+                request, data["name"], spec_dhss, is_public=data["is_public"])
             if set_dict:
-                # NOTE(vponomaryov): remove following when
-                # bug #1435819 is fixed.
-                if "driver_handles_share_servers" not in set_dict.keys():
-                    set_dict["driver_handles_share_servers"] = spec_dhss
-
                 manila.share_type_set_extra_specs(
                     request, share_type.id, set_dict)
 
@@ -220,11 +219,12 @@ class UpdateShareType(forms.SelfHandlingForm):
             if unset_list:
                 get = manila.share_type_get_extra_specs(
                     request, self.initial["id"])
-                for unset_key in unset_list:
-                    # NOTE(vponomaryov): skip keys that are already unset
-                    if unset_key in get.keys():
-                        manila.share_type_unset_extra_specs(
-                            request, self.initial["id"], unset_key)
+
+                # NOTE(vponomaryov): skip keys that are already unset
+                to_unset = set(unset_list).intersection(set(get.keys()))
+                if to_unset:
+                    manila.share_type_unset_extra_specs(
+                        request, self.initial["id"], to_unset)
             msg = _("Successfully updated extra specs for share type '%s'.")
             msg = msg % self.initial['name']
             messages.success(request, msg)
