@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -157,7 +155,7 @@ class UpdateRow(tables.Row):
 
 
 def get_size(share):
-    return _("%sGB") % share.size
+    return _("%sGiB") % share.size
 
 
 class SharesTableBase(tables.DataTable):
