@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -101,7 +99,12 @@ class DetailView(tabs.TabView):
 
 class CreateView(forms.ModalFormView):
     form_class = share_form.CreateForm
+    form_id = "create_share"
     template_name = 'project/shares/shares/create.html'
+    modal_header = _("Create Share")
+    modal_id = "create_share_modal"
+    submit_label = _("Create")
+    submit_url = reverse_lazy("horizon:project:shares:create")
     success_url = reverse_lazy("horizon:project:shares:index")
     page_title = _('Create a Share')
 
@@ -116,7 +119,12 @@ class CreateView(forms.ModalFormView):
 
 class UpdateView(forms.ModalFormView):
     form_class = share_form.UpdateForm
+    form_id = "update_share"
     template_name = 'project/shares/shares/update.html'
+    modal_header = _("Edit Share")
+    modal_id = "update_share_modal"
+    submit_label = _("Edit")
+    submit_url = "horizon:project:shares:update"
     success_url = reverse_lazy("horizon:project:shares:index")
     page_title = _('Edit Share')
 
@@ -133,7 +141,8 @@ class UpdateView(forms.ModalFormView):
 
     def get_context_data(self, **kwargs):
         context = super(UpdateView, self).get_context_data(**kwargs)
-        context['share'] = self.get_object()
+        args = (self.get_object().id,)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
@@ -173,7 +182,13 @@ class UpdateMetadataView(forms.ModalFormView):
 
 class AddRuleView(forms.ModalFormView):
     form_class = share_form.AddRule
+    form_id = "rule_add"
     template_name = 'project/shares/shares/rule_add.html'
+    modal_header = _("Add Rule")
+    modal_id = "rule_add_modal"
+    submit_label = _("Add")
+    submit_url = "horizon:project:shares:rule_add"
+    success_url = reverse_lazy("horizon:project:shares:index")
     page_title = _('Add Rule')
 
     def get_object(self):
@@ -189,7 +204,8 @@ class AddRuleView(forms.ModalFormView):
 
     def get_context_data(self, **kwargs):
         context = super(AddRuleView, self).get_context_data(**kwargs)
-        context['share'] = self.get_object()
+        args = (self.get_object().id,)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
@@ -232,25 +248,26 @@ class ManageRulesView(tables.DataTableView):
 
 class ExtendView(forms.ModalFormView):
     form_class = share_form.ExtendForm
+    form_id = "extend_share"
     template_name = 'project/shares/shares/extend.html'
+    modal_header = _("Extend Share")
+    modal_id = "extend_share_modal"
+    submit_label = _("Extend")
+    submit_url = "horizon:project:shares:extend"
     success_url = reverse_lazy("horizon:project:shares:index")
     page_title = _('Extend Share')
 
+    @memoized.memoized_method
     def get_object(self):
-        if not hasattr(self, "_object"):
-            share_id = self.kwargs['share_id']
-            try:
-                self._object = manila.share_get(self.request, share_id)
-            except Exception:
-                msg = _('Unable to retrieve share.')
-                url = reverse('horizon:project:shares:index')
-                exceptions.handle(self.request, msg, redirect=url)
-        return self._object
+        try:
+            return manila.share_get(self.request, self.kwargs['share_id'])
+        except Exception:
+            exceptions.handle(self.request, _('Unable to retrieve share.'))
 
     def get_context_data(self, **kwargs):
         context = super(ExtendView, self).get_context_data(**kwargs)
-        context['share'] = self.get_object()
-
+        args = (self.get_object().id,)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         try:
             context['usages'] = quotas.tenant_limit_usages(self.request)
         except Exception:
@@ -260,8 +277,18 @@ class ExtendView(forms.ModalFormView):
 
     def get_initial(self):
         share = self.get_object()
-        return {'share_id': self.kwargs["share_id"],
-                'name': share.name,
-                'orig_size': share.size,
-                'new_size': int(share.size) + 1
-                }
+        if not share or isinstance(share, Exception):
+            raise exceptions.NotFound()
+        return {
+            'share_id': self.kwargs["share_id"],
+            'name': share.name or share.id,
+            'orig_size': share.size,
+            'new_size': int(share.size) + 1,
+        }
+
+    def form_invalid(self, form):
+        context = super(ExtendView, self).get_context_data()
+        context = self._populate_context(context)
+        context['form'] = form
+        context['submit_url'] = reverse(self.submit_url, kwargs=self.kwargs)
+        return self.render_to_response(context)
