@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -31,6 +29,9 @@ from manila_ui.dashboards.project.shares import views
 urlpatterns = patterns(
     'openstack_dashboard.dashboards.project.shares.views',
     url(r'^$', views.IndexView.as_view(), name='index'),
+    url(r'^\?tab=share_tabs__snapshots_tab$',
+        views.IndexView.as_view(),
+        name='snapshots_tab'),
     url(r'^create/$', shares_views.CreateView.as_view(), name='create'),
     url(r'^create_security_service$',
         security_services_views.CreateView.as_view(),
