@@ -644,3 +644,64 @@ class SnapshotsTests(test.BaseAdminViewTests):
             mock.ANY, search_opts={'all_tenants': True})
         api_manila.share_list.assert_called_once_with(mock.ANY)
         self.assertRedirectsNoFollow(res, INDEX_URL)
+
+
+class ShareTypeTests(test.BaseAdminViewTests):
+
+    def setUp(self):
+        super(self.__class__, self).setUp()
+        self.share_type = test_data.share_type
+        self.url = reverse('horizon:admin:shares:update_type',
+                           args=[self.share_type.id])
+        self.mock_object(
+            api_manila, "share_type_get",
+            mock.Mock(return_value=self.share_type))
+        self.mock_object(
+            api_keystone, "tenant_list",
+            mock.Mock(return_value=(keystone_data.projects, None)))
+        self.mock_object(
+            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
+        # Reset taken list of projects to avoid test interference
+        utils.PROJECTS = {}
+
+    def test_create_share_type(self):
+        url = reverse('horizon:admin:shares:create_type')
+        data = {
+            'is_public': True,
+            'name': 'my_share_type',
+            'spec_driver_handles_share_servers': 'False'
+        }
+        form_data = data.copy()
+        form_data['spec_driver_handles_share_servers'] = 'false'
+        self.mock_object(api_manila, "share_type_create")
+
+        res = self.client.post(url, data)
+
+        api_manila.share_type_create.assert_called_once_with(
+            mock.ANY, form_data['name'],
+            form_data['spec_driver_handles_share_servers'],
+            is_public=form_data['is_public'])
+        self.assertRedirectsNoFollow(res, INDEX_URL)
+
+    def test_update_share_type_get(self):
+        res = self.client.get(self.url)
+
+        api_manila.share_type_get.assert_called_once_with(
+            mock.ANY, self.share_type.id)
+        self.assertNoMessages()
+        self.assertTemplateUsed(res, 'admin/shares/update_share_type.html')
+
+    def test_update_share_type_post(self):
+        data = {
+            'extra_specs': 'driver_handles_share_servers=True'
+        }
+        form_data = {
+            'extra_specs': {'driver_handles_share_servers': 'True'},
+        }
+        self.mock_object(api_manila, "share_type_set_extra_specs")
+
+        res = self.client.post(self.url, data)
+
+        api_manila.share_type_set_extra_specs.assert_called_once_with(
+            mock.ANY, self.share_type.id, form_data['extra_specs'])
+        self.assertRedirectsNoFollow(res, INDEX_URL)
